@@ -3,7 +3,8 @@ DEFAULT_API_URL <- "http://localhost:8989"
 ENDPOINTS <- list(
   route = "route",
   spt = "spt",
-  info = "info"
+  info = "info",
+  isochrone = "isochrone"
 )
 
 AVAILABLE_SPT_COLUMNS <- c(
